@@ -1,5 +1,6 @@
 import six
 
+import django
 from django import forms
 from django.conf import settings
 from django.core.exceptions import ValidationError
@@ -128,7 +129,7 @@ class CropDusterThumbFormField(ModelMultipleChoiceField):
 
 class CropDusterInlineFormSet(BaseGenericFileInlineFormSet):
 
-    fields = ('image', 'thumbs', 'attribution', 'attribution_link', 'caption')
+    fields = ('image', 'thumbs', 'attribution', 'attribution_link', 'caption', 'field_identifier')
 
     def _construct_form(self, i, **kwargs):
         """
@@ -139,11 +140,18 @@ class CropDusterInlineFormSet(BaseGenericFileInlineFormSet):
 
         form = super(CropDusterInlineFormSet, self)._construct_form(i, **kwargs)
 
+        field_identifier_field = form.fields['field_identifier']
+        field_identifier_field.widget = forms.HiddenInput()
+        field_identifier_field.initial = self.field_identifier
+
         thumbs_field = form.fields['thumbs']
 
         if form.instance and form.instance.pk:
             # Set the queryset to the current list of thumbs on the image
-            thumbs_field.queryset = form.instance.thumbs.get_query_set()
+            if django.VERSION < (1, 7):
+                thumbs_field.queryset = form.instance.thumbs.get_query_set()
+            else:
+                thumbs_field.queryset = form.instance.thumbs.get_queryset()
         else:
             # Start with an empty queryset
             thumbs_field.queryset = Thumb.objects.none()
