@@ -67,6 +67,18 @@ class Thumb(models.Model):
     def __unicode__(self):
         return self.name
 
+    @property
+    def image_file(self):
+        return Image.get_file_for_size(image=self.image, size_name=self.name)
+
+    @property
+    def url(self):
+        return self.image_file.url if self.image_file else ''
+
+    @property
+    def path(self):
+        return self.image_file.path if self.image_file else ''
+
     def save(self, *args, **kwargs):
         if self.pk:
             try:
@@ -182,6 +194,7 @@ class Image(models.Model):
     content_type = models.ForeignKey(ContentType)
     object_id = models.PositiveIntegerField(null=True, blank=True)
     content_object = generic.GenericForeignKey('content_type', 'object_id')
+    field_identifier = models.SlugField(null=True, blank=True)
 
     prev_object_id = models.PositiveIntegerField(null=True, blank=True)
     prev_content_object = generic.GenericForeignKey('content_type', 'prev_object_id')
@@ -203,12 +216,12 @@ class Image(models.Model):
 
     attribution = models.CharField(max_length=255, blank=True, null=True)
     attribution_link = models.URLField(max_length=255, blank=True, null=True)
-    caption = models.CharField(max_length=255, blank=True, null=True)
+    caption = models.TextField(blank=True, null=True)
 
     class Meta:
         app_label = cropduster_settings.CROPDUSTER_APP_LABEL
         db_table = '%s_image' % cropduster_settings.CROPDUSTER_DB_PREFIX
-        unique_together = ("content_type", "object_id", "prev_object_id")
+        unique_together = ("content_type", "object_id", "field_identifier")
 
     def __unicode__(self):
         return self.get_image_url()
@@ -217,6 +230,10 @@ class Image(models.Model):
     def path(self):
         return self.image.name if self.image else None
 
+    @property
+    def url(self):
+        return self.image.url if self.image else None
+
     @property
     def extension(self):
         ''' returns the file extension with a dot (.) prepended to it '''
@@ -259,7 +276,7 @@ class Image(models.Model):
         preview_file = cls.get_file_for_size(image_file, '_preview')
         img_save_params = {}
         if preview_img.format == 'JPEG':
-            img_save_params['quality'] = 95
+            img_save_params['quality'] = cropduster_settings.get_jpeg_quality(w, h)
         preview_img.save(safe_str_path(preview_file.path), **img_save_params)
         return preview_file
 
@@ -296,17 +313,31 @@ class Image(models.Model):
 
     def save(self, **kwargs):
         self.date_modified = datetime.now()
+        if self.field_identifier == "":
+            self.field_identifier = None
         if not self.pk and self.content_type and self.object_id:
             try:
-                original = Image.objects.get(content_type=self.content_type, object_id=self.object_id,
-                        prev_object_id__isnull=True)
+                original = Image.objects.get(content_type=self.content_type,
+                                             object_id=self.object_id,
+                                             field_identifier=self.field_identifier,
+                                             prev_object_id__isnull=True)
             except Image.DoesNotExist:
                 pass
             else:
                 original.prev_object_id = original.object_id
                 original.object_id = None
                 original.save()
-        return super(Image, self).save(**kwargs)
+
+        super(Image, self).save(**kwargs)
+
+        # If the Image has changed, we need to make sure the related field on the
+        # model class has also been updated
+        model_class = self.content_type.model_class()
+        for field, _ in model_class._meta.get_fields_with_model():
+            if (isinstance(field, CropDusterImageField) and
+                    field.generic_field.field_identifier == self.field_identifier):
+                model_class.objects.filter(pk=self.object_id).update(**{field.attname: self.path})
+                break
 
     def get_image_url(self, size_name='original', tmp=False):
         converted = Image.get_file_for_size(self.image, size_name, tmp=tmp)
@@ -394,7 +425,7 @@ class Image(models.Model):
     def _save_thumb(self, size, image=None, thumb=None, ref_thumb=None, tmp=False, standalone=False):
         img_save_params = {}
         if image.format == 'JPEG':
-            img_save_params['quality'] = 95
+            img_save_params['quality'] = cropduster_settings.get_jpeg_quality(self.width, self.height)
 
         if not thumb:
             if standalone:
