@@ -362,7 +362,7 @@ CKEDITOR.dialog.add('cropduster', function (editor) {
     var tabElements = [{
         id: 'iframe',
         type: 'html',
-        html: '<div style="width:100%;text-align:center;">' + '<iframe style="border:0;width:650px;height:500px;font-size:20px" scrolling="no" frameborder="0" allowTransparency="true"></iframe>' + '</div>',
+        html: '<div style="width:100%;text-align:center;">' + '<iframe style="border:0;width:650px;height:400px;font-size:20px" scrolling="no" frameborder="0" allowTransparency="true"></iframe>' + '</div>',
         onLoad: function (widget) {},
         setup: function (widget) {
 
@@ -379,7 +379,7 @@ CKEDITOR.dialog.add('cropduster', function (editor) {
 
             cropdusterIframe = {
                 setup: function (domId, baseUrl) {
-                    this.iframeElement = CKEDITOR.document.getById(domId).getChild(0);
+                    this.iframeElement = CKEDITOR.document.getById(domId).getChild(0)
                     this.baseUrl = baseUrl;
                     this.callback_fn = domId.replace(/_uiElement$/, '') + '_callback';
 
@@ -418,7 +418,7 @@ CKEDITOR.dialog.add('cropduster', function (editor) {
                     var url = this.getUrl();
                     this.iframeElement.$.src = url;
                 }
-            };
+            }
             cropdusterIframe.setup(this.domId, widget.config.url + '?');
             widget.cropdusterIframe = cropdusterIframe;
 
