@@ -1,9 +1,15 @@
-from jsonutil import jsonutil
+import six
+from six.moves import filter
+import json
+
 from cropduster.resizing import Size
 
 
+__all__ = ('dumps', 'loads')
+
+
 def json_default(obj):
-    if callable(getattr(obj, '__serialize__', None)):
+    if six.callable(getattr(obj, '__serialize__', None)):
         dct = obj.__serialize__()
         module = obj.__module__
         if module == '__builtin__':
@@ -37,9 +43,11 @@ def object_hook(dct):
 
 def dumps(obj, *args, **kwargs):
     kwargs.setdefault('default', json_default)
-    return jsonutil.dumps(obj, *args, **kwargs)
+    return json.dumps(obj, *args, **kwargs)
 
 
 def loads(s, *args, **kwargs):
+    if isinstance(s, six.binary_type):
+        s = s.decode('utf-8')
     kwargs.setdefault('object_hook', object_hook)
-    return jsonutil.loads(s, *args, **kwargs)
+    return json.loads(s, *args, **kwargs)
