@@ -1,5 +1,7 @@
 from __future__ import division
 
+import six
+
 from . import jsonutils as json
 from ..resizing import Size
 
@@ -10,9 +12,9 @@ __all__ = ('get_min_size',)
 def get_min_size(sizes):
     """Determine the minimum required width & height from a list of sizes."""
     min_w, min_h = 0, 0
-    if sizes == u'null':
+    if sizes == 'null':
         return (0, 0)
-    if isinstance(sizes, basestring):
+    if isinstance(sizes, six.string_types):
         sizes = json.loads(sizes)
     if not sizes:
         return (0, 0)
